# Generated by Django 3.1 on 2020-08-23 18:33

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ModelExample',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30)),
                ('occupation', models.CharField(choices=[('study', 'Study'), ('work', 'Work')], max_length=100, verbose_name='Occupation')),
                ('study', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name Institution')),
                ('semester', models.CharField(blank=True, max_length=100, null=True, verbose_name='Semester')),
                ('company', models.CharField(blank=True, max_length=100, null=True, verbose_name='Company')),
                ('position', models.CharField(blank=True, max_length=100, null=True, verbose_name='Position')),
                ('nick', models.CharField(blank=True, max_length=100, null=True, verbose_name='Add NickName?')),
                ('nickname', models.CharField(blank=True, max_length=100, null=True, verbose_name='Nick Name')),
            ],
            options={
                'verbose_name': 'Model Example',
                'verbose_name_plural': 'Model Example',
            },
        ),
        migrations.CreateModel(
            name='ThemeUI',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name_theme', models.CharField(default='', max_length=200)),
                ('applied', models.BooleanField(help_text='If you select this, the previously applied theme is inactivated, if there is none selected by default, the one from django remains')),
                ('title_window', models.CharField(max_length=200, default='')),
                ('site_name', models.CharField(max_length=200, default='')),
                ('body_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('header_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('header_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('breadcrumbs_color', models.CharField(blank=True, default='#c4dce8', max_length=20, null=True)),
                ('breadcrumbs_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('module_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('module_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('sidebar_current_model_bg_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('section_link_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('link_color', models.CharField(blank=True, default='#447e9b', max_length=20, null=True)),
                ('link_hover_color', models.CharField(blank=True, default='#036', max_length=20, null=True)),
                ('section_link_visited_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('sidebar_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('content_related_bg_color', models.CharField(blank=True, default='#f8f8f8', max_length=20, null=True)),
                ('content_related_title_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('content_related_sub_title_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('quiet_color', models.CharField(blank=True, default='#999', max_length=20, null=True)),
                ('button_tools_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('button_tools_bg_color', models.CharField(blank=True, default='#999', max_length=20, null=True)),
                ('button_tools_hover_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('button_tools_hover_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('th_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('th_bg_color', models.CharField(blank=True, default='#f6f6f6', max_length=20, null=True)),
                ('tr_even_bg_color', models.CharField(blank=True, default='#f9f9f9', max_length=20, null=True)),
                ('paginator_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('paginator_bg_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('paginator_border_color', models.CharField(blank=True, default='#eee', max_length=20, null=True)),
                ('submit_delete_button_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_delete_button_bg_color', models.CharField(blank=True, default='#ba2121', max_length=20, null=True)),
                ('submit_delete_button_bg_hover_color', models.CharField(blank=True, default='#a41515', max_length=20, null=True)),
                ('submit_save_primary_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_save_primary_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('submit_save_primary_bg_hover_color', models.CharField(blank=True, default='#205067', max_length=20, null=True)),
                ('submit_save_secondary_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_save_secondary_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('submit_save_secondary_bg_hover_color', models.CharField(blank=True, default='#609ab6', max_length=20, null=True)),
                ('cancel_button_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('cancel_button_bg_color', models.CharField(blank=True, default='#ddd', max_length=20, null=True)),
                ('cancel_button_bg_hover_color', models.CharField(blank=True, default='#ccc', max_length=20, null=True)),
                ('alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('alert_message_bg_color', models.CharField(blank=True, default='#dfd', max_length=20, null=True)),
                ('error_alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('error_alert_message_bg_color', models.CharField(blank=True, default='#ffefef', max_length=20, null=True)),
                ('warning_alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('warning_alert_message_bg_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
            ],
            options={
                'verbose_name_plural': 'Settings UI',
            },
        ),
    ]
